@@ -4,6 +4,7 @@ from supervisely.nn.artifacts import (
     YOLOv5v2,
     YOLOv8,
     MMClassification,
+    MMPretrain,
     MMSegmentation,
     MMDetection,
     MMDetection3,
@@ -19,6 +20,7 @@ class FrameworkName:
     YOLOV5V2 = "YOLOv5 2.0"
     YOLOV8 = "YOLOv8+"
     MMCLASSIFICATION = "MMClassification"
+    MMPRETRAIN = "MMPretrain"
     MMSEGMENTATION = "MMSegmentation"
     MMDETECTION = "MMDetection"
     MMDETECTION3 = "MMDetection 3.0"
@@ -34,6 +36,7 @@ class FrameworkMapper:
         FrameworkName.YOLOV5V2: YOLOv5v2,
         FrameworkName.YOLOV8: YOLOv8,
         FrameworkName.MMCLASSIFICATION: MMClassification,
+        FrameworkName.MMPRETRAIN: MMPretrain,
         FrameworkName.MMSEGMENTATION: MMSegmentation,
         FrameworkName.MMDETECTION: MMDetection,
         FrameworkName.MMDETECTION3: MMDetection3,
